#
# spec file for package mate-control-center
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define   soname          libmate-window-settings
%define   sover           1
%define   soname_slab     libmate-slab
%define   sover_slab      0
%define   _version        1.28

Name:           mate-control-center
Version:        1.28.0
Release:        1.4
Summary:        MATE Desktop control center
License:        GPL-2.0-or-later
Group:          System/GUI/Other
URL:            https://mate-desktop.org/
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  mate-common
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(accountsservice)
BuildRequires:  pkgconfig(atk)
%ifnarch ppc64le s390x
BuildRequires:  pkgconfig(ayatana-appindicator3-0.1)
%endif
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(dconf) >= 0.11.0
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(libgtop-2.0)
BuildRequires:  pkgconfig(libmarco-private) >= %{_version}
BuildRequires:  pkgconfig(libmate-menu) >= %{_version}
BuildRequires:  pkgconfig(libmatekbd)
BuildRequires:  pkgconfig(libmatekbdui)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libxklavier)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mate-desktop-2.0) >= %{_version}
BuildRequires:  pkgconfig(mate-settings-daemon) >= %{_version}
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(polkit-gobject-1)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udisks2)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xscrnsaver)
Requires:       %{name}-branding >= %{_version}
Requires:       gsettings-backend-dconf
Requires:       gsettings-desktop-schemas
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires
%if 0%{?is_opensuse}
BuildRequires:  pkgconfig(appindicator3-0.1)
%endif

%description
The control center is MATE's main interface for configuration of various
aspects of your desktop.

%package branding-upstream
Summary:        The MATE Control Center -- Upstream Definition of Shell Content
Requires:       %{name} = %{version}
Supplements:    (%{name} and branding-upstream)
Conflicts:      %{name}-branding
Provides:       %{name}-branding = %{version}
BuildArch:      noarch
#BRAND: This package contains the definitions of the content appearing
#BRAND: in the shell (/etc/xdg/menus/matecc.menu).

%description branding-upstream
The control center is MATE's main interface for configuration of
various aspects of your desktop.

This package provides the upstream definition of what appears in the
control center.

%package devel
Summary:        Header files for MATE Control Center
Group:          Development/Libraries/X11

%description devel
The control center is MATE's main interface for configuration of various
aspects of your desktop.

This package provides MATE control center development files.

%lang_package

%prep
%autosetup -p1

%build
%configure \
  --disable-static        \
  --disable-update-mimedb
%make_build

%install
%make_install

rm -f %{buildroot}%{_datadir}/applications/mimeinfo.cache
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name} %{?no_lang_C}

%suse_update_desktop_file mate-settings-mouse
%suse_update_desktop_file mate-network-properties
%suse_update_desktop_file mate-appearance-properties
%suse_update_desktop_file mate-keybinding
%suse_update_desktop_file -r mate-font-viewer GTK Utility Settings DesktopSettings
%suse_update_desktop_file mate-theme-installer
%suse_update_desktop_file mate-default-applications-properties

%fdupes -s %{buildroot}%{_datadir}

%files
%license COPYING
%doc NEWS README
%{_sbindir}/mate-display-properties-install-systemwide
%{_bindir}/mate-*
%{_datadir}/applications/*.desktop
%{_datadir}/mate-control-center/*
%dir %{_datadir}/mate-time-admin
%{_datadir}/mate-time-admin/*
%{_datadir}/mime/packages/mate-theme-package.xml
%{_datadir}/polkit-1/actions/org.mate.randr.policy
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/help/C/%{name}/
%{_datadir}/icons/hicolor/*/*/*.png
%{_datadir}/icons/hicolor/scalable/apps/*.svg
%{_datadir}/thumbnailers/
# From upstream branding.
%exclude %{_sysconfdir}/xdg/menus/matecc.menu
%dir %{_datadir}/desktop-directories
%{_datadir}/desktop-directories/matecc.directory
%{_mandir}/man?/mate-*.?%{?ext_man}

%files branding-upstream
%dir %{_sysconfdir}/xdg/menus
%config %{_sysconfdir}/xdg/menus/matecc.menu

%files devel
%{_libdir}/pkgconfig/mate-default-applications.pc
%{_libdir}/pkgconfig/mate-keybindings.pc

%files lang -f %{name}.lang

%changelog
* Mon Mar 25 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.28.0
  * Translations update
  * Meson: fix mate-time-admin directory error
  * Add meson build support
  * Remove libslab library
  * appearance: Fix compilation warnings replace deprecated functions
  * common: Fix compilation warnings replace deprecated functions
    gtk_rc_get_theme_dir and gtk_rc_scanner_new
  * typing-break: Force dependency on appindicator and remove deprecated
    GtkStatusIcon
  * typing-break: Fix compilation warnings and replace deprecated functions
  * Remove  "libwindow settings" that are no longer in use
  * capplets/display: Fix compilation warnings and replace deprecated functions
  * libslab: Fix compilation warnings and replace deprecated functions
  * font-viewer: Fix compilation warnings and replace deprecated functions
  * appearance: Remove useless match_wm_manager_init function
  * Add new capplets: system info
  * tx: fix warnings in Japanese and Serbian translations
  * Update glib2 dependency version from 2.50 to 2.64
  * libslab: Remove gdk/gdkx.h from includes
  * Wayland: remove xisms from screen width detection
  * windows: Fix UI accessibility (#704)
  * windows: Fix spacing in the Compositing Manager tab
  * Fix implicit conversion changes signedness: 'gboolean' to 'guint'
  * keybindings: fix memory leak
  * appearance: use mate_image_menu_item replace gtk_image_menu_item
  * keyboard: fix memory leak
* Mon May 15 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.26.1:
  * keybindings: fix memory leak.
  * keyboard: Fix memory leaks.
  * appearance-style: Fix memory leak.
  * common: Fix memory leaks.
  * appearance: Fix memory leak.
  * mate-da-capplet: Fix memory leak.
  * mouse: Fix memory leak.
  * Change capplets/about-me/mate-about-me-password.c.
  * Remove redundant i18n functions.
  * Maintain compatibility with Glibc versions older than 2.66
  * Update translations.
* Tue Aug 10 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * Translations update
  * Replace the deprecated GtkTable with GtkGrid
  * Replace the deprecated gtk_widget_set_state with gtk_widget_set_state_flags
  * Remove useless and discarded gtk_button_released
  * Replace the deprecated g_bookmark_file_get_modified with
    g_bookmark_file_get_modified_date_time
  * Fix compilation warning
  * Use gtk-cancel icon replace window-close icon
  * update copyright to 2021
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.24.2:
  * Translations update
  * Default applications: Add flac/x-flac format (mime-type) for media
* Sun Aug 16 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.1:
  * mate-theme-info: Use of memory after it is freed.
  * build: Silent build warnings for distcheck.
  * Use default MATE_COMPILE_WARNINGS level.
  * Port libslab_handle_g_error to the built-in GLib logging
    framework.
  * mate-about-me: Fix memory leak.
  * appearance: Fix memory leak.
  * Do not collect the translation for Icon.
  * Update translations.
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0 (changes since 1.23.1):
  * mouse: Add support for Acceleration Profiles
  * appearance: Fix memory leak.
  * appearance: Add new font for user.
  * Stop propagate error.
  * at-properties: Migrate from dbus-glib to gdbus.
  * Fix UI validation.
  * time-admin: Add license info in time-admin.ui file.
  * Search system themes in system data dirs.
  * display: Enable help button.
  * windows: Add window-properties.ui.
  * Avoid redundant redeclarations.
  * keybindings: Fix schema creation in makefile.
  * appearance: Fix desktop file creation.
  * shell: Fix typo in keyword name.
  * Migrate from intltool to gettext.
  * default-applications: Load icons as cairo surfaces.
  * icons: Force uniform size on icons.
  * remove warning: "__sun" is not defined, evaluates to 0.
  * fv: thumbnailer: Add font/collection to the supported
    mimetypes.
  * font-viewer: Add font/ttf and font/otf mime types.
  * time-admin: Fix memory leak.
  * time-admin: Don't share «void QuitApp(TimeAdmin *ta)» method.
  * default-applications: Remove messenger options from ui file.
  * time-admin: Remove unreachable code.
  * time-admin: Simplify date & time displaying.
  * time-admin: Save button cannot be enabled if NTP
    synchronisation is active.
  * time-admin: Display current time in time-admin.ui on startup.
  * time-admin: Rename adjustament to adjustment in time-admin.ui.
  * time-admin: A11y time-admin.ui.
  * time-admin: Add time-admin.ui.
  * default-applications: Fix Word Processor top margin.
  * Update translations
- Drop support for old openSUSE versions.
* Fri Jul 19 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.23.1 (changes since 1.22.1):
  * Translations update
  * fix build error when not installed gla11y
  * remove lightdm-settings support
  * launch lightdm-settings if installed
  * use current running DM preferences program
  * support lightdm-gtk-greeter-settings as login preferences program
  * drop libXxf86 dependency
  * Use python3 for gla11y
  * Add scroll tabs with mouse wheel in severals capplets
  * avoid deprecated g_type_class_add_private
  * time-admin: smaller fixes.
  * use theme's icon preferences-system-time
  * common: Remove capplet-stock-icons
  * bump require of m-s-d and m-d
  * Add orca to Visual combo box if available
  * Add support for checking .ui accessibility with gla11y
  * Do not reload NTP and modify the button arrangement when starting the service
  * Authentication to add modification time
  * Use default color to set label and remove the maximum button
  * use Makefile pkgdatadir
  * g_date_time_unref datetime
  * Display the correct time when selecting the time zone
  * Memory leak: g_error_free(error);
  * Modify mate-time-admin.desktop.in file format
  * enable to build time-admin for mate-control-center
  * add time-admin source code
  * add timezone translation files for time-admin
  * add image resources for time-admin applet
  * Populate initial messenger list with irc scheme handler apps
  * Set default icq/irc/ircs/sip/xmpp scheme handler
  * Add instant messenger keybinding into mate-keybinding-properties
  * Change the icon for instant messaging application
  * default-applications: Add a widget for a default messenger application
  * appearance.ui (cursor size scale)
  * Fix the icon sizes in Preferred Applications selector
  * capplets: Use gresources for UI files
  * Fix grammar mistake
  * Migrate from dbus-glib to GDBus
  * Use system data dirs to locate key bindings
  * control-center: Fix memory leak
  * Use GtkSeparatorMenuItem in Apparence preview
  * default-applications: Improve UI accessibility
  * Use keyboard device icon like in other hardware devices
  * Use icons provided by themes and remove not used icons
  * help: update copyright
  * add installation instructions
- remove patch:
  * mate-control-center-gtk-3.20.patch: we don't support gtk3.20
    anymore
- remove dependency on xxf86misc as it was dropped upstream, fixes
  boo#1139857
- build require gtk >= 3.22, gio >= 2.50 and glib >= 2.50
- add mate-time-admin:
  * package its files
  * add dependency on polkit-gobject-1
* Sun May 12 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.22.1:
  * default-applications: Improve UI accessibility.
  * Use keyboard device icon like in other hardware devices.
  * control-center: Fix memory leak.
  * Use GtkSeparatorMenuItem in Apparence preview.
  * Remove dead store detected by clang.
  * Use icons provided by themes and remove not used icons.
  * help: Update copyright.
  * Update translations
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * Depend on mate-desktop 1.21.2+ due to new the gschema key.
  * Bump required version of mate-menus.
  * Require mate-settings-daemon 1.21.2+.
  * Use new mate-menus api.
  * appearance: Add buttons-have-icons switch.
  * mouse: Add middle button emulation switch.
  * Avoid deprecated GtkStock.
  * Remove useless parameter in mate_theme_install_real.
  * theme-installer.c: Add tips when reinstall a existed theme.
  * Mouse: Include a toggle to enable or disable middlemouse paste.
  * capplets/keybindings: Avoid deprecated gdk_keymap_get_default.
  * display-capplet.ui: Replace deprecations.
  * libslab: Code clean up.
  * wm-common: Replace deprecated gdk_error_trap functions.
  * libslab: Replace deprecated gtk_menu_popup.
  * msd-input-helper: Replace deprecated gdk_error_trap functions.
  * mouse: Replace deprecated gdk_error_trap functions.
  * keybindings: Add a key binding to toggle the microphone's mute
    status.
  * keybindings: Add some key bindings to control volume quietly.
  * Account for nullptr error when we see G_IO_STATUS_EOF.
  * typing-break: Replace deprecated gdk_error_trap functions.
  * mate-keybinding-properties: Avoid deprecated
    "gtk_widget_ensure_style".
  * Add search option for mate-font-viewer.
  * Load avatar-default as default image.
  * A fix for accounts service support.
  * keybindings: Add a key binding to launch settings.
  * Add UI to control
    org.mate.accessibility-keyboard.stickykeys-latch-to-lock.
  * Use fixed size to show user icon.
  * Add new api for EImageChooser.
  * get/set user face icon use accounts service.
  * eggcellrendererkeys: Avoid deprecated gtk_widget_modify_bg/fg.
  * Update MCC help.
  * default-applications: Use more common icon names for Office
    documents.
  * mate-display-properties: Migrate from dbus-glib to GDBus.
  * Fix the runtime warning about gtk_widget_destroy.
  * Fixed number of cols error after reload menus.
  * Fixed crash when install/remove application.
  * capplets/mouse: .svg files instead .png in doubleclick artwork.
  * capplets/mouse: New doubleclick artwork with mate logo.
  * default-applications: Fix assertion failture on
    g_icon_to_string.
  * default-applications: Add a widget for a default calculator
    application.
  * Update translations.
- Rebase mate-control-center-gtk-3.20.patch.
* Sat Dec 22 2018 sor.alexei@meowr.ru
- Update to version 1.20.4:
  * Disable deprecation warnings for distcheck.
  * default-applications: Use the selected word processor for RTF
    as well.
  * typing-break: Make images larger and load as surface.
  * Update hint for mouse double-click.
  * keybindings: Double click instead one click to edit keyboard
    shortcuts.
  * Fix spelling and grammar mistakes.
  * Update legal.xml.
  * Use make functions for HELP_LINGUAS.
  * Update translations.
- Rebase mate-control-center-gtk-3.20.patch.
* Sat Jun 16 2018 sor.alexei@meowr.ru
- Update to version 1.20.3:
  * display-capplet: Add css name for scrollarea.
  * Change cursor-size to 24px.
  * Update translations.
* Wed Apr 11 2018 sor.alexei@meowr.ru
- Update to version 1.20.2:
  * Add auto-detect toggle switch for font DPI.
  * Fix screen geometry when snapping windows on rotated displays.
  * Fix segfaults in theme installers.
  * Scale cursor size for HiDPI when changing themes.
* Wed Mar 14 2018 crrodriguez@opensuse.org
- remove xorg-x11-devel, adjusting buildrequires to what
  configure checks for and what libraries are linked in
  the final executable.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * Add support for HiDPI displays.
  * libslab nameplate-tile, shellwindow: Replace GtkAlignment with
    a GtkBox.
  * libslab tile.c: Replace deprecated gtk_widget_set_state().
  * libslab slab-section, app-shell, searchbar: Avoid deprecated
    GtkAlignment.
  * app-resizer: Fix a build warning
  * libslab nameplate-tile: Avoid deprecated
    gtk_button_set_focus_on_click().
  * libslab nameplate-tile: Remove one deprecated usage of
    GtkAlignment.
  * libslab: Don't use deprecated gdk_app_launch_context_new().
  * eel-alert-dialog: Replace some GtkStock items.
  * keybindings: Fix a couple of build warnings.
  * libslab bookmark-agent: Fix some xdg paths.
  * Use g_object_unref() instead of deprecated rsvg_handle_free().
  * keybindings: Fix and add mnemonics in the custom command
    dialogue.
  * keybindings: Allow to select an installed application through a
    dialogue.
  * libslab: Avoid deprecated gdk_screen_width/height().
  * appearance-font.c: Avoid deprecated
    gdk_screen_get_width/height_mm().
  * Avoid deprecated gdk_screen_get_width/height().
  * libslab: Drop an unneeded libslab_mate_desktop_item_open_help()
    function.
  * libslab: Drop uneeded support for gnome-main-menu.
  * typing-break: Avoid deprecated GDK pointer and keyboard types.
  * libslab: Don't use deprecated gtk_show_uri().
  * display scrollarea: Avoid deprecated gtk_adjustment_changed.
  * keybindings eggcellrendererkey: Avoid deprecated GDK pointer
    and keyboard types.
  * display scrollarea: Fix a -Wuninitialized build warning.
  * display scrollarea: Avoid deprecated gdk_window_get_pointer().
  * Avoid deprecated gdk_screen_get_monitor_,
    gdk_screen_make_display_name(), gdk_display_get_screen() and
    gdk_display_get_n_screens() functions.
  * capplet-util: Don't use deprecated gtk_show_uri().
  * typing-break: Avoid deprecated GtkMisc, gtk_alignment_new().
  * mouse: Fix a build warning.
  * mouse: Warn about enabling multi-finger emulation.
  * Enable default broswer setting support for text/html.
  * libslab: Restore missing variable initialisation.
  * An implementation of WidthOfScreen and HeightOfScreen.
  * Fix support for external localisations in .desktop files.
  * Add the support for cursor sizes of 96 and 128.
  * man: Fix the title of the mate-window-properties page.
  * man: Fix titles of the mate-typing-monitor and
    mate-thumbnail-font pages.
  * Fix font dpi with "org.mate.desktop.font-rendering.dpi" by
    default.
  * theme-installer.c: Add missing g_object_unref in
    mate_theme_install_real.
  * theme-util.c: Fix reinstalling the deleted theme can cause
    failure.
  * Support the theme compression package for installing XZ format.
  * eggcellrendererkeys.c: Fix build warnings.
  * theme-thumbnail.c: Fix build warnings with 'write' and 'pipe'.
  * libslab: Store the search entry widget as GtkEntry.
  * libslab: Fix the search icon being misaligned.
  * libslab: search-entry.c: Fix a build warning.
  * Remove a useless duplication in mate_theme_install_real.
  * Fix Window Border theme cannot be deleted.
  * Update the windows tiling gsettings key.
  * shell: Add a Comment field to the .desktop file.
  * Update translations.
- Add mate-control-center-gtk-3.20.patch: Restore GLib 2.48 and
  GTK+ 3.20 support.
* Sat Jun 17 2017 sor.alexei@meowr.ru
- Update to version 1.18.2:
  * libslab: Make ThemedIcon use style_updated instead of style_set.
  * libslab: Correct icon loading code.
  * about-me-password UI: Set max_width_chars for description-label.
  * Restore Polish translation credits from GNOME.
  * Update translations.
* Tue Apr  4 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Add support for switching themes on Metacity >= 3.20.
  * appearance-ui: Add primary-toolbar style class for toolbar in
    interface preview.
  * keyboard-properties-xkbot: Avoid deprecated GtkAlignment.
  * theme-thumbnail: Avoid deprecated GtkAlignment.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Build: Require libmatekbd, libmate-desktop, marco,
    mate-settings-daemon >= 1.17.
  * Build: Require XCursor and XInput unconditionally.
  * Move to GTK+3 (require GTK+ >= 3.14), drop the GTK+2 code and
  - -with-gtk build option.
  * Port from libunique to GtkApplication.
  * Rework font-viewer: Add font browsing mode, support for TTC
    fonts, and make it appear in the menus.
  * Add libinput support for mouse and touchpad.
  * Mouse: Add a separate touchpad motion settings on touchpad tab.
  * Mouse: Change tab label from General to Mouse.
  * Mouse: Change natural scroll mnemonic from 'a' to 'n'.
  * Fix lots of GTK+ deprecations.
  * Some more fixes and cleanups.
  * Update translations.
* Wed Feb  8 2017 sor.alexei@meowr.ru
- Update to version 1.16.1:
  * Appearance: Fix live updating of the various theme details.
  * Appearance: Fix vertical expand of content on window resize in
    GTK+3 build.
  * Keyboard: Fix vertical expand of content on window resize in
    GTK+3 build.
  * Shell: Force icon size in libslab to avoid huge icons.
  * GTK+3: Fix build with Marco 1.17.
  * Fix a couple of memleaks.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Build: Drop dconf 0.10 compatibility.
  * Appearance: Change default hinting style to slight and render
    antialiasing samples using that style.
  * Appearance: Render hinting samples using RGBA antialiasing.
  * Appearance: Place theme name below theme preview in GTK+3
    build to match GTK+2 one.
  * Appearance: Center theme name in GTK+3 build to match GTK+2
    one.
  * Appearance: Hide Colours tab in Customise Theme dialogue in
    the GTK+3 build as changing theme colours doesn't work in GTK+3.
  * GTK+3: Fix build with appindicator support enabled.
  * GTK+3: Fix showing monitors in display properties with
    GLib 2.49.6.
  * GTK+3: Fix various deprecations.
  * Some code cleanups.
* Sun Aug 14 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * About me: Add some space between username and buttons.
  * About me: Fix UI freeze when changing the password.
  * Make distcheck use currently selected GTK+ version.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Touchpad settings: Support edge and two-finger scrolling
    independently.
  * Some more fixes and cleanups.
  * Update translations.
  * Fix Changelog generation
* Mon Feb 22 2016 sor.alexei@meowr.ru
- Update to version 1.13.2:
  * Fix more deprecations and warnings.
* Fri Feb  5 2016 sor.alexei@meowr.ru
- Update to version 1.13.1:
  * Fix build warnings about incorrect pointer types.
  * GTK+3: Fix several deprecations.
  * GTK+3: Fix theme previews in mate-appearance-properties.
  * Drop "Ubuntu hacks" (--enable-ubuntu build option) as Ubuntu
    dropped that stuff long ago.
* Tue Jan 26 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * Move preferences-categories.menu to mate-menus.
  * Drop MateConf migration script.
  * Window properties: Make all three window focus modes selectable.
  * Gtk3: Fix some deprecations.
  * Fix more build warnings.
* Mon Dec  7 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Display: Fix crash due to a regression.
  * Fix some bottom items being not accessible in some cases.
  * Some more fixes.
  * Update translations.
- Enable SNI-tray (appindicators) support.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0:
  * Appearance: restored Interface tab.
  * Display: show output names in addition to display names.
  * Keybindings: added keybinding for logout.
  * Touchpad settings: add option to enable/disable touchpad.
  * Improve categorisation.
  * Retrieve strings directly from gschema (requires intltool
    0.50.1).
  * Some more fixes and cleanups.
* Fri Oct  9 2015 sor.alexei@meowr.ru
- Update to 1.11:
  * Switch to org.gnome.SessionManager.
  * Display settings: add support to set the primary monitor.
  * Gtk2 Restored Interface tab in Appearance capplet.
  * Touchpad settings: add support for natural scrolling, 2 finger
    and 3 finger clicks.
  * Gtk3: Fix font rendering in Appearance and mate-font-viewer.
* Mon Oct  5 2015 sor.alexei@meowr.ru
- Update to 1.10.2:
  * Appearance: fix possible segmentation fault on closing.
  * Appearance: allow to save notification theme optionally.
  * Display: made changing refresh rate actually work.
  * Fix build with prefix other than /usr.
  * Help fixes.
  * Update translations.
* Mon Jul 13 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Appearance: add theme changing support for metacity >= 3.16.
  * Help fixes.
  * GTK+3 fixes.
  * Translations update.
* Mon May  4 2015 p.drouand@gmail.com
- Update to version 1.10.0
  * No changes since version 1.9.1
* Thu Jan 22 2015 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  * Adapt to MateDesktop MateRR* API changes
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + windows: Add option to configure titlebar buttons layout
  + appearance: Add support for metacity-theme-2.xml
  + default-applications: Add support for office applications
* Fri Oct  3 2014 p.drouand@gmail.com
- Update to version 1.8.3
  + Fixed typo in togglekeys-enable (a11y)
  + Fixed segfault with custom key bindings
  + Added support for metacity-2 themes in appearance capplet
  + Added several man pages
  + Added keywords key to .desktop files
  + Updated Marco WM name
* Sat Jul 12 2014 p.drouand@gmail.com
- Update to version 1.8.2
  + Fix key name typo in mate-keyboard
  + Allow metacity-2 themes
  + Several man page and desktop file fixes
* Sat Mar 15 2014 p.drouand@gmail.com
- Update to version 1.8.1
  + default-applications: add support for accessibility applications
- Symlink duplicate files with fdupes
* Mon Mar 10 2014 p.drouand@gmail.com
- Package files in /usr/share/mate-control-center but don't own this
  directory to avoid conflicts with marco
- Fix versions in BuildRequires tags
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Wed Feb 19 2014 p.drouand@gmail.com
- Update to version 1.7.90 (unstable)
  + use yelp-tools instead of mate-doc-utils
  + windows: Add option to enable side by side tiling
  + windows: Add metacity support
  + appearance: Add support for 'artist' tag in xml backgrounds files
  + appearance: Change also titlebar font if Metacity is running
* Mon Feb 10 2014 p.drouand@gmail.com
- Update to version 1.7.0 (unstable)
  + initial GTK3 support
  + about-me: Remove unused constant
  + fix some gcc warnings
  + windows: Fix ui file after GtkComboBoxText migration
  + fixes for GTK2
  + remove all separator occurrences
  + keyboard: Fix segfault
    Var may be set as constant value but freed later.
- Replace mate-doc-utils requirement with yelp-tools; upstream use it
  now to build documentation
* Wed Jan  1 2014 p.drouand@gmail.com
- Update to version 1.6.2
  + default applications: fix capplet name
  + Fix some deprecations and remove some unused vars
  + appearance: Change also titlebar font if Metacity is running
    Closes #40 (https://github.com/mate-desktop/mate-control-center/issues/40)
  + Rename .desktop files to avoid file collision with Gnome2
  + use MATE defaults for appearance-themes
  + using mate-default-applications-properties.desktop im gsettings schema
- Upstream doesn't provide display-properties.desktop, keyboard.desktop
  at-properties.desktop and window-properties.desktop anymore; remove
  %%suse_update_desktop_file tag for mentioned desktop files
- Subpackage libslab development files in his own package
* Fri Sep 20 2013 p.drouand@gmail.com
- Correct library subpackages group to System/Libraries
* Tue Sep  3 2013 p.drouand@gmail.com
- Add "Requires: gsettings-desktop-schemas" to allow to share settings
  with others DEs
* Mon Sep  2 2013 p.drouand@gmail.com
- mate-control-center' help files must be in main package, not in
  lang package; correct it
* Sat Aug  3 2013 p.drouand@gmail.com
- Update to version 1.6.1
  + fixes for make dist and make distcheck
  + add manpage for default-applications, appearance and about-me
  + rename also desktop file for MATE
  + fix multiply defined AM_CPPFLAGS/INCLUDES in /shell/Makefile.am
  + add X-MATE-PersonalSettings to default-applications.desktop
  + update default-applications.desktop.in.in and move mate-about-me
    to personal category
  + mouse: remove unused code and fix loading of GSettings prefs
  + fix pkgconfig files path
    closes #47 https://github.com/mate-desktop/mate-control-center/issues/47
  + fix mate-keybinding segfaults after setting custom keybinding
    closes #45 https://github.com/mate-desktop/mate-control-center/issues/45
  + make appearance and keybindings windows maximizable
    closes #35 https://github.com/mate-desktop/mate-control-center/issues/35
  + add support for Compiz 0.9.x
* Wed Apr 24 2013 p.drouand@gmail.com
- Add "Requires: libslab0" in devel package; mate-control-center-devel
  provides pkgconfig(libslab) and need to requires it
* Fri Apr 12 2013 p.drouand@gmail.com
- Add "Requires: gsettings-backend-dconf"; it's needed to save users settings
  changes
* Wed Apr  3 2013 p.drouand@gmail.com
- Update to version 1.6
  + Add Recommends:     %%{name}-lang = %%{version}-%%{release}
  + change INCLUDES to AM_CPPFLAGS for automake-1.13
* Tue Apr  2 2013 p.drouand@gmail.com
- Update to version 1.5.5
  + fix GSettings variable name
  + fix dconf minimum versions
* Sun Feb 24 2013 p.drouand@gmail.com
- Remove Requires: mate-control-center in devel package
  It only needs the libraries subpackage
- Remove rpmlintrc file
  Issue has been fixed
* Tue Feb 19 2013 p.drouand@gmail.com
- Update to version 1.5.4:
  * Dont use removed GSettings allowed-keys for keybindings
  * Fix disabled shortcuts values:
    Disabled shortcuts have "disabled" as value in GSettings, not an
    empty string
  * Allow to set default terminal emulator
  * Translated Spanish comments
  * Fix some small issues
  * Fix image viewer icon
    Closes https://github.com/mate-desktop/mate-control-center/issues/36
  * Fix touchpad scrolling settings
    Closes https://github.com/mate-desktop/mate-control-center/issues/34
  * Add option to enable compositing manager and fast alt-tab
  * Display mate-control-center in menu
-Removed patchs; fixed and merged on upstream release:
  * Fix-touchpad-scrolling-settings.patch
  * fix-wrong-desktop-names.patch
* Tue Feb 12 2013 p.drouand@gmail.com
-Add Fix-touchpad-scrolling-settings.patch
* Sun Feb 10 2013 p.drouand@gmail.com
- Add fix-wrong-desktop-names.patch
* Thu Jan 24 2013 nmo.marques@gmail.com
- Update to version 1.5.3
  + changed ordering that titlebar actions are displayed
  + set metacity theme if compiz or metacity are being used
  + minor updated
* Wed Dec 19 2012 nmo.marques@gmail.com
- Update to version 1.5.2
* Wed Dec 12 2012 nmo.marques@gmail.com
- Update to version 1.5.1 (testing snapshot):
  + build and deploy libslab (testing)
- Split libslab sub-package and minor spec file fixes
* Sun Nov 25 2012 nmo.marques@gmail.com
- Update to version 1.5.1
  + Fix FSF addresses
  + remove old mateconf key declarations
  + fix background settings;
  + fix up function headers for consistency
  + migrate applets to gsettings
  + other fixes
- Remove mate-control-center-1.5.0-fix_missing_return.patch; fixed
  upstream
* Sun Nov  4 2012 nmo.marques@gmail.com
- Add %%post/%%postun desktop database macros
- Disable 'aboutme' module build for now; currently being reworked
  upstream and broken on Factory - need glib 2.34+ fix
- Remove libebook-1.2 dependency from BRs; only 'aboutme' requires
  it and its dropped by upstream.
* Sat Oct 27 2012 nmo.marques@gmail.com
- Update to version 1.5.0
  + migration to DBus/GSettings from old CORBA/mateconf-2.0
- Add missing macros for %%post and %%postun
- Merge library devel sub-package with main devel sub-package
- Add mate-control-center-1.5.0-fix_missing_return.patch - fix
  function otherwise breaks in build system - upstreamed
* Sat Sep  8 2012 nmo.marques@gmail.com
- update to version 1.4.0
  + enable 'about-me'
  + add missing Xorg dependencies for modules
- remove mate-1.2.1-add_gmodules_to_linker.patch: fixed upstream
- remove mate-1.2.1-fix_pointer.patch: fixed upstream
- copypac to X11:MATE
  + minor cosmetic fixes
* Sat Jun 16 2012 nmo.marques@gmail.com
- update to version 1.2.1
  + move spec to use mateconf macros, minor spec cleanups
- add mate-1.2.1-add_gmodules_to_linker.patch: add GMODULES to
  linker path
- add mate-1.2.1-fix_pointer.patch: disable a bit of bit used for
  a transiction in Ubuntu (wtf ?)
* Wed Feb  1 2012 fisiu@opensuse.org
- initial package from version 1.1.0
